<?php
/**
 * Description: ConnectPOS Integration with Polylang.
 * Author: ConnectPOS
 *
 * @package ConnectPOS\Integration
 */

namespace ConnectPOS\Integration;

/**
 * Class Cpos_Polylang
 * @package ConnectPOS\Integration
 */
class Cpos_Polylang {

    const LOCALE_META_KEY = 'locale';

    /**
     * Polylang constructor.
     * @return void
     */
    public function __construct() {
        if ( ! class_exists( 'Polylang_Woocommerce' ) ) {
            return;
        }

        add_action( 'rest_api_init', function () {
            register_rest_field(
                'product',
                'meta_data',
                [
                    'get_callback'    => [ $this, 'cppl_get_product_locale' ],
                    'update_callback' => [ $this, 'update_locale_for_product' ],
                    'schema'          => [ 'type' => 'array' ]
                ]
            );
        } );
    }

    /**
     * @param mixed $object
     *
     * @return mixed
     */
    public function cppl_get_product_locale( $object ) {
        $url_permalink = parse_url( $object['permalink'] );
        $url_path      = $url_permalink['path'];
        $url_path_arr  = explode( '/', trim( $url_path ) );
        $locale        = pll_default_language();

        foreach ( $url_path_arr as $index => $element ) {
            $prev_element = $url_path_arr[ $index - 1 ];
            if ( $element === 'product' && strlen( $prev_element ) === 2 ) {
                $locale = $prev_element;
            }
        }

        $object['meta_data'][] = [ 'key' => self::LOCALE_META_KEY, 'value' => $locale ];

        return $object['meta_data'];
    }
}